@@ -1,8 +1,8 @@
 /*---------------------------------------------------------------------------*\
 **$Author: andrius $
-**$Date: 2017-12-27 14:47:34 +0200 (Tr, 27 gruod. 2017) $ 
-**$Revision: 5899 $
-**$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/components/codcif/common.c $
+**$Date: 2019-03-19 10:36:32 +0200 (An, 19 kov. 2019) $ 
+**$Revision: 6846 $
+**$URL: svn://www.crystallography.net/cod-tools/tags/v2.4/src/components/codcif/common.c $
 \*---------------------------------------------------------------------------*/
 
 /* exports: */
@@ -206,14 +206,11 @@ int is_real( char *s )
     if( *s == '\0' ) return 1;
 
     if( *s != '(' &&
-        *s != 'E' && *s != 'e' &&
-        *s != 'D' && *s != 'd' /* Fortranish :) */
-        ) {
+        *s != 'E' && *s != 'e' ) {
         return 0;
     }
 
-    if( *s == 'E' || *s == 'e' ||
-        *s == 'D' || *s == 'd' ) {
+    if( *s == 'E' || *s == 'e' ) {
         s ++;
         if( *s == '+' || *s == '-' ) s++;
         if( !isdigit(*s) ) {
