@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
-#$Author: andrius $
-#$Date: 2018-01-19 11:31:52 +0200 (Pn, 19 saus. 2018) $ 
-#$Revision: 5952 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/AuthorNames.pm $
+#$Author: antanas $
+#$Date: 2019-04-04 13:28:06 +0300 (Kt, 04 bal. 2019) $ 
+#$Revision: 6889 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.4/src/lib/perl5/COD/AuthorNames.pm $
 #------------------------------------------------------------------------------
 #*
 #* Subroutines for parsing and regularisation of author names.
@@ -127,9 +127,6 @@ sub parse_author_name
         $author_escaped =~ s/\n/\\n/g;
         $UCS_author_escaped =~ s/\n/\\n/g;
             warn "WARNING, name '$author_escaped'"
-                . ( $unparsed_name eq $UCS_author
-                ? ''
-                : " ('$UCS_author_escaped')" )
                 . " contains symbol '$symbol_escaped' "
                 . 'that is not permitted in names' . "\n";
         if( ! $name_syntax_explained ) {
@@ -205,10 +202,7 @@ sub parse_author_name
             $parsed_name{'first'} = $2;
             $parsed_name{'initials'} = $3;
         } else {
-            warn "NOTE, name '$unparsed_name'"
-                . ( $unparsed_name eq $UCS_author ? ''
-                    : " ('$UCS_author')" )
-                    . ' seems unusual' . "\n";
+            warn "NOTE, name '$unparsed_name' seems unusual" . "\n";
             if( ! $name_syntax_explained ) {
                 warn 'NOTE, ' . get_name_syntax_description() . "\n";
                 $name_syntax_explained = 1;
