@@ -1,8 +1,8 @@
  #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2017-11-22 17:50:19 +0200 (Tr, 22 lapkr. 2017) $ 
-#$Revision: 5883 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/CIF/Data/AtomList.pm $
+#$Date: 2019-04-08 11:59:00 +0300 (Pr, 08 bal. 2019) $ 
+#$Revision: 6901 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.4/src/lib/perl5/COD/CIF/Data/AtomList.pm $
 #------------------------------------------------------------------------------
 #*
 #  Construct a common data structure, representing list of atoms in
@@ -17,7 +17,8 @@ use Clone qw( clone );
 use COD::Algebra::Vector qw( modulo_1 );
 use COD::AtomProperties;
 use COD::CIF::Data qw( get_cell );
-use COD::CIF::Tags::Manage qw( new_datablock set_loop_tag );
+use COD::CIF::Tags::Manage qw( new_datablock set_loop_tag set_tag );
+use COD::CIF::Tags::Print qw( print_cif );
 use COD::Spacegroups::Symop::Algebra qw( symop_invert symop_mul
                                          symop_vector_mul );
 use COD::Spacegroups::Symop::Parse qw( string_from_symop
@@ -121,7 +122,7 @@ sub extract_atom
                   _atom_site_fract_y
                   _atom_site_fract_z ) ) {
         push ( @atom_xyz, $values->{$_}[$number] );
-        $atom_xyz[-1] =~ s/[(]\d+[)]$//;
+        $atom_xyz[-1] =~ s/[(][0-9]+[)]$//;
     }
 
     if( $options->{modulo_1} ) {
@@ -287,7 +288,7 @@ sub is_atom_excludable
     if( $criteria->{'has_zero_occupancies'} &&
         defined $values->{'_atom_site_occupancy'} ) {
         my $occupancy = $values->{'_atom_site_occupancy'}[$number];
-        $occupancy =~ s/[(]\d+[)]$//; # remove precision
+        $occupancy =~ s/[(][0-9]+[)]$//; # remove precision
         if( $occupancy eq '?' || $occupancy eq '.' || $occupancy == 0.0 ) {
             return 1;
         }
@@ -373,12 +374,12 @@ sub atom_array_from_cif($$)
         $atom_site_tag = '_atom_site_label';
     } elsif( exists $values->{'_atom_site_type_symbol'} ) {
         $atom_site_tag = '_atom_site_type_symbol';
-        warn 'WARNING, \'_atom_site_label\' data item was not found -- a '
+        warn 'WARNING, data item \'_atom_site_label\' was not found -- a '
            . 'serial number will be appended to the \'_atom_site_type_symbol\' '
            . 'data item values to make atom labels' . "\n";
     } else {
-        die 'ERROR, neither \'_atom_site_label\' nor '
-          . '\'_atom_site_type_symbol\' data item present' . "\n";
+        die 'ERROR, neither data item \'_atom_site_label\' nor '
+          . 'data item \'_atom_site_type_symbol\' was found' . "\n";
     }
 
     my $atom_labels = $values->{$atom_site_tag};
@@ -816,7 +817,7 @@ sub atom_groups
                     } elsif ( $occupancy eq '.' ) {
                         $occupancy = 0;
                     } else {
-                        $occupancy =~ s/[(]\d+[)]$//; # remove precision
+                        $occupancy =~ s/[(][0-9]+[)]$//; # remove precision
                     }
 
                     if ( !defined $max_group_occupancy{$group} ) {
@@ -1143,32 +1144,39 @@ sub dump_atoms_as_cif
 {
     my ($datablock_name, $atom_list, $cell) = @_;
 
-    local $\ = "\n";
+    my $datablock = new_datablock( $datablock_name );
 
-    print "data_", $datablock_name;
+    set_tag( $datablock, '_space_group_name_H-M_alt', 'P 1' );
 
-    print "_symmetry_space_group_name_H-M ", "'P 1'";
-    print "_cell_length_a ", $$cell[0] if defined $$cell[0];
-    print "_cell_length_b ", $$cell[1] if defined $$cell[1];
-    print "_cell_length_c ", $$cell[2] if defined $$cell[2];
-
-    print "_cell_angle_alpha ", $$cell[3] if defined $$cell[3];
-    print "_cell_angle_beta  ", $$cell[4] if defined $$cell[4];
-    print "_cell_angle_gamma ", $$cell[5] if defined $$cell[5];
-
-    print "loop_";
-    print "_atom_site_label";
-    print "_atom_site_fract_x";
-    print "_atom_site_fract_y";
-    print "_atom_site_fract_z";
-
-    for my $atom (@$atom_list) {
-        print
-            $atom->{name}, " ",
-            $atom->{coordinates_fract}[0], " ",
-            $atom->{coordinates_fract}[1], " ",
-            $atom->{coordinates_fract}[2];
+    my @cell_tags = qw( _cell_length_a
+                        _cell_length_b
+                        _cell_length_c
+                        _cell_angle_alpha
+                        _cell_angle_beta
+                        _cell_angle_gamma );
+    for (0..5) {
+        next if !defined $$cell[$_];
+        set_tag( $datablock, $cell_tags[$_], $$cell[$_] );
     }
+
+    set_loop_tag( $datablock,
+                  '_atom_site_label',
+                  '_atom_site_label',
+                  [ map { $_->{name} } @$atom_list ] );
+    set_loop_tag( $datablock,
+                  '_atom_site_fract_x',
+                  '_atom_site_label',
+                  [ map { $_->{coordinates_fract}[0] } @$atom_list ] );
+    set_loop_tag( $datablock,
+                  '_atom_site_fract_y',
+                  '_atom_site_label',
+                  [ map { $_->{coordinates_fract}[1] } @$atom_list ] );
+    set_loop_tag( $datablock,
+                  '_atom_site_fract_z',
+                  '_atom_site_label',
+                  [ map { $_->{coordinates_fract}[2] } @$atom_list ] );
+
+    print_cif( $datablock );
 }
 
 1;
