@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
-#$Author: andrius $
-#$Date: 2018-10-11 14:59:55 +0300 (Kt, 11 spal. 2018) $
-#$Revision: 6469 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/CIF/Data/CODNumbers.pm $
+#$Author: antanas $
+#$Date: 2019-02-28 11:30:29 +0200 (Kt, 28 vas. 2019) $
+#$Revision: 6710 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.4/src/lib/perl5/COD/CIF/Data/CODNumbers.pm $
 #------------------------------------------------------------------------------
 #*
 #  Find COD numbers of duplicate structures.
@@ -607,8 +607,8 @@ sub have_equiv_category_values
         my $val_1 = $entry_1->{$category}{$tag};
         my $val_2 = $entry_2->{$category}{$tag};
         if ( $val_1 =~ /^${number}$/o || $val_2 =~ /^${number}$/o ) {
-            $val_1 =~ s/\(\d+\)$//;
-            $val_2 =~ s/\(\d+\)$//;
+            $val_1 =~ s/\([0-9]+\)$//;
+            $val_2 =~ s/\([0-9]+\)$//;
             return 0 if ( $val_1 != $val_2 )
         } else {
             $val_1 =~ s/^\s+|\s+$//g;
