@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2018-07-17 17:28:29 +0300 (An, 17 liep. 2018) $ 
-#$Revision: 6311 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/CIF/Data/CellContents.pm $
+#$Date: 2019-02-28 11:30:29 +0200 (Kt, 28 vas. 2019) $ 
+#$Revision: 6710 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.4/src/lib/perl5/COD/CIF/Data/CellContents.pm $
 #------------------------------------------------------------------------------
 #*
 #  Calculate unit cell contents from the atomic coordinates and
@@ -144,7 +144,7 @@ sub atomic_composition($$$@)
             $atom->{atom_site_occupancy} ne '.' &&
             $atom->{atom_site_occupancy} ne '?'
                 ? $atom->{atom_site_occupancy} : 1;
-        $occupancy =~ s/\(\d+\)\s*$//;
+        $occupancy =~ s/\([0-9]+\)\s*$//;
 
         my $attached_hydrogens = 0;
         if( exists $atom->{attached_hydrogens} &&
