@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------
-#$Author: andrius $
-#$Date: 2019-01-21 09:23:55 +0200 (Pr, 21 saus. 2019) $ 
-#$Revision: 6648 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/CIF/Tags/Manage.pm $
+#$Author: antanas $
+#$Date: 2019-04-05 16:31:39 +0300 (Pn, 05 bal. 2019) $ 
+#$Revision: 6892 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.4/src/lib/perl5/COD/CIF/Tags/Manage.pm $
 #------------------------------------------------------------------------
 #* 
 #  CIF tag management functions that work on the internal
@@ -39,10 +39,29 @@ our @EXPORT_OK = qw(
     set_loop_tag
     get_data_value
     get_aliased_value
+    contains_data_item
 );
 
 sub rename_tags($$$);
 
+##
+# Evaluates if a data frame contains the specified data item.
+#
+# @param $cif
+#       Data frame as returned by the CIF::COD::Parser.
+# @param $tag
+#       Data name of the data item.
+# @return
+#       '1' if the data frame contain the data block,
+#       '0' otherwise.
+##
+sub contains_data_item
+{
+    my ( $cif, $tag ) = @_;
+
+    return defined $cif->{'values'}{$tag} ? 1 : 0;
+}
+
 sub exclude_tag
 {
     my ($cif, $tag) = @_;
@@ -66,16 +85,17 @@ sub exclude_tag
 sub tag_is_empty
 {
     my ($cif, $tag) = @_;
-    my $is_empty =1;
 
-    if( exists $cif->{values}{$tag} ) {
-        for my $val (@{$cif->{values}{$tag}}) {
-            if( defined $val && $val ne '?' && $val ne '.' ) {
-                $is_empty = 0;
-                last;
-            }
+    return 1 if !contains_data_item( $cif, $tag );
+
+    my $is_empty =1;
+    for my $val (@{$cif->{values}{$tag}}) {
+        if( defined $val && $val ne '?' && $val ne '.' ) {
+            $is_empty = 0;
+            last;
         }
     }
+        
     return $is_empty;
 }
 
@@ -117,16 +137,17 @@ sub exclude_empty_non_loop_tags
 sub tag_is_unknown
 {
     my ($cif, $tag) = @_;
+
+    return 1 if !contains_data_item( $cif, $tag );
     my $is_empty =1;
 
-    if( exists $cif->{values}{$tag} ) {
-        for my $val (@{$cif->{values}{$tag}}) {
-            if( defined $val && $val ne '?' ) {
-                $is_empty = 0;
-                last;
-            }
+    for my $val (@{$cif->{values}{$tag}}) {
+        if( defined $val && $val ne '?' ) {
+            $is_empty = 0;
+            last;
         }
     }
+
     return $is_empty;
 }
 
@@ -177,7 +198,7 @@ sub exclude_misspelled_tags
     }
     my %misspelled_tags = map { $_ => 1 } @misspelled_tags;
     for my $misspelled_tag (@misspelled_tags) {
-        next if !exists $cif->{values}{$misspelled_tag};
+        next if !contains_data_item( $cif, $misspelled_tag );
         if( !exists $cif->{inloop}{$misspelled_tag} ) {
             exclude_tag( $cif, $misspelled_tag );
         } else {
@@ -201,26 +222,37 @@ sub exclude_misspelled_tags
 
 sub new_datablock
 {
-    my( $dataname ) = @_;
+    my( $dataname, $cifversion ) = @_;
 
-    die 'data block name can not be empty' if !$dataname;
+    die 'data block name cannot be empty' if !$dataname;
 
-    my $dataname_now = $dataname;
-    $dataname_now =~ s/[ \t\r\n]/_/g;
-    if( $dataname ne $dataname_now ) {
-        warn "data block name '$dataname' was renamed to " .
-             "'$dataname_now' as data block names can not contain spaces";
+    my $dataname_old = $dataname;
+    $dataname =~ s/[ \t\r\n]/_/g;
+    if( $dataname ne $dataname_old ) {
+        warn "data block name '$dataname_old' was renamed to " .
+             "'$dataname' as data block names cannot contain spaces";
+    }
+
+    my( $major, $minor ) = ( 1, 1 );
+    if( $cifversion ) {
+        ( $major, $minor, my @rest ) = split /\./, $cifversion;
+        warn 'patch version for CIF format is ignored' if @rest;
+        $major = int( $major );
+        $minor = int( $minor );
+        if( "$major.$minor" ne '1.1' && "$major.$minor" ne '2.0' ) {
+            die "unknown CIF format version '$cifversion'";
+        }
     }
 
     return {
-        name   => $dataname_now,
+        name   => $dataname,
         tags   => [],
         values => {},
         types  => {},
         precisions => {},
         loops  => [],
         inloop => {},
-        cifversion => { major => 1, minor => 1 }
+        cifversion => { major => $major, minor => $minor }
     };
 }
 
@@ -233,7 +265,7 @@ sub order_tags
     # Correct non-loop tags + _publ_author_name
 
     for my $tag (@{$tags_to_print}) {
-        if(  exists $cif->{values}{$tag} &&
+        if(  contains_data_item( $cif, $tag ) &&
              exists $dictionary_tags->{$tag} &&
            (!exists $cif->{inloop}{$tag} ||
             $tag eq '_publ_author_name') ) {
@@ -253,7 +285,7 @@ sub order_tags
     # Correct loop tags
 
     for my $tag (@{$loop_tags_to_print}) {
-        if( exists $cif->{values}{$tag} &&
+        if( contains_data_item( $cif, $tag ) &&
             exists $cif->{inloop}{$tag} &&
             $tag ne '_publ_author_name' ) {
             push @new_tag_list, $tag;
@@ -327,7 +359,7 @@ sub rename_tag
 {
     my ($cif, $old_tag, $new_tag ) = @_;
 
-    return if !exists $cif->{values}{$old_tag};
+    return if !contains_data_item( $cif, $old_tag );
 
     $cif->{values}{$new_tag} = $cif->{values}{$old_tag};
     delete $cif->{values}{$old_tag} if $new_tag ne $old_tag;
@@ -388,11 +420,9 @@ sub rename_tags($$$)
 {
     my ( $dataset, $tags2rename, $prefix ) = @_;
 
-    my $values = $dataset->{values};
     my %renamed_tags = ();
-
     for my $tag (@{$tags2rename}) {
-        next if !exists $values->{$tag};
+        next if !contains_data_item( $dataset, $tag );
         next if exists $dataset->{inloop}{$tag};
 
         my $new_tag = $prefix . $tag;
@@ -406,7 +436,8 @@ sub rename_tags($$$)
 sub set_tag
 {
     my ( $cif, $tag, $value ) = @_;
-    if( !exists $cif->{values}{$tag} ) {
+
+    if ( !contains_data_item( $cif, $tag ) ) {
         push @{$cif->{tags}}, $tag;
     }
     $cif->{values}{$tag}[0] = $value;
