@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------
 #$Author: andrius $
-#$Date: 2017-10-25 18:00:27 +0300 (Tr, 25 spal. 2017) $ 
-#$Revision: 5657 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/CIF/Tags/Print.pm $
+#$Date: 2019-03-15 13:36:30 +0200 (Pn, 15 kov. 2019) $ 
+#$Revision: 6793 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.4/src/lib/perl5/COD/CIF/Tags/Print.pm $
 #------------------------------------------------------------------------
 #* 
 #  CIF tag management functions that work on the internal
@@ -40,15 +40,17 @@ sub print_cif
 
     my $fold_long_fields = 0;
     my $folding_width;
+    my $is_save_block;
 
-    if( $flags && ref $flags eq "HASH" ) {
-        $fold_long_fields = $flags->{fold_long_fields}
-            if defined $flags->{fold_long_fields};
-        $folding_width = $flags->{folding_width}
-            if defined $flags->{folding_width};
-        %dictionary_tags = %{$flags->{dictionary_tags}}
-            if defined $flags->{dictionary_tags};
-    }
+    $flags = {} unless $flags && ref $flags eq 'HASH';
+    $fold_long_fields = $flags->{fold_long_fields}
+        if defined $flags->{fold_long_fields};
+    $folding_width = $flags->{folding_width}
+        if defined $flags->{folding_width};
+    %dictionary_tags = %{$flags->{dictionary_tags}}
+        if defined $flags->{dictionary_tags};
+    $is_save_block = $flags->{is_save_block}
+        if defined $flags->{is_save_block};
 
     my $cif_version = '1.1';
     if( exists $dataset->{cifversion} ) {
@@ -59,12 +61,12 @@ sub print_cif
 
     clean_cif( $dataset, $flags );
 
-    if( int $cif_version > 1 ) {
+    if( !$is_save_block && int $cif_version > 1 ) {
         print '#\#CIF_', $cif_version, "\n";
     }
 
     if( defined $dataset->{name} ) {
-        print "data_", $dataset->{name}, "\n";
+        print $is_save_block ? 'save_' : 'data_', $dataset->{name}, "\n";
     }
 
     my $tag_msg = "Tags that were not found in dictionaries";
@@ -126,6 +128,16 @@ sub print_cif
     if( $loop_tags_encountered ) {
         print "#END $loop_tag_msg\n";
     }
+
+    if( int $cif_version == 2 || !$is_save_block ) {
+        for my $save_block (@{$dataset->{save_blocks}}) {
+            print_cif( $save_block, { %$flags, is_save_block => 1 } );
+        }
+    }
+
+    if( $is_save_block ) {
+        print "save_\n";
+    }
 }
 
 #
@@ -315,7 +327,7 @@ sub sprint_value
                                             $cif_version );
             }
             if( @values ) {
-                return "[ @values ]";
+                return "\n[ @values ]";
             } else {
                 return '[ ]';
             }
@@ -326,7 +338,7 @@ sub sprint_value
                 if( ($key =~ /'''/ && $key =~ /"""/) ||
                     ($key =~ /'''/ && $key =~ /"$/) ||
                     ($key =~ /"""/ && $key =~ /'$/) ) {
-                    die "ERROR, can not store value '$key' " .
+                    die "ERROR, cannot store value '$key' " .
                         'in a quoted string' . "\n";
                 } elsif( $key =~ /'/ && $key =~ /"/ && $key =~ /'$/ ) {
                     $key = '"""' . $key . '"""';
