@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2015-11-09 12:17:48 +0200 (Pr, 09 lapkr. 2015) $ 
-#$Revision: 4237 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/Precision.pm $
+#$Date: 2019-02-28 11:30:29 +0200 (Kt, 28 vas. 2019) $ 
+#$Revision: 6710 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.4/src/lib/perl5/COD/Precision.pm $
 #------------------------------------------------------------------------
 
 package COD::Precision;
@@ -47,7 +47,7 @@ sub unpack_cif_number
 {
     my( $number ) = @_;
     my $sigma;
-    if( $number =~ s/\((\d+)\)$// ) {
+    if( $number =~ s/\(([0-9]+)\)$// ) {
         $sigma = $1;
     }
     my $precision;
