@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------
 #$Author: antanas $
-#$Date: 2016-01-12 16:22:02 +0200 (An, 12 saus. 2016) $ 
-#$Revision: 4529 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/SOptions.pm $
+#$Date: 2019-02-28 11:30:29 +0200 (Kt, 28 vas. 2019) $ 
+#$Revision: 6710 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.4/src/lib/perl5/COD/SOptions.pm $
 #------------------------------------------------------------------------
 #* 
 #  Simple option processing package
@@ -89,8 +89,8 @@ sub get_value
 
 #-----------------------------------------------------------------------------
 
-my $integer = '[-+]? \d+';
-my $float = '[-+]? (\d+(\.\d*)? | (\.\d+)) ([eE][-+]?\d+)?';
+my $integer = '[-+]? [0-9]+';
+my $float = '[-+]? ([0-9]+(\.[0-9]*)? | (\.[0-9]+)) ([eE][-+]?[0-9]+)?';
 
 sub get_int
 {
