@@ -1,8 +1,8 @@
 #------------------------------------------------------------------------
-#$Author: andrius $
-#$Date: 2018-07-18 15:30:39 +0300 (Tr, 18 liep. 2018) $ 
-#$Revision: 6321 $
-#$URL: svn://www.crystallography.net/cod-tools/tags/v2.3/src/lib/perl5/COD/Spacegroups/Symop/Parse.pm $
+#$Author: antanas $
+#$Date: 2019-02-28 11:14:03 +0200 (Kt, 28 vas. 2019) $ 
+#$Revision: 6709 $
+#$URL: svn://www.crystallography.net/cod-tools/tags/v2.4/src/lib/perl5/COD/Spacegroups/Symop/Parse.pm $
 #------------------------------------------------------------------------
 #* 
 #**
@@ -63,7 +63,7 @@ sub symop_from_string
                 $symop[$n][2] = $sign;
             }
             else {
-                if( $value =~ m/(\d+)\/(\d+)/ ) {
+                if( $value =~ m/([0-9]+)\/([0-9]+)/ ) {
                     $value = $1 / $2;
                 }
                 $symop[$n][3] = $sign * $value;
@@ -199,7 +199,7 @@ sub is_symop_parsable
 
     my $status = 1;
 
-    my $symop_term = '(?:x|y|z|\d|\d*\.\d+|\d+\.\d*|\d/\d)';
+    my $symop_term = '(?:x|y|z|[0-9]|[0-9]*\.[0-9]+|[0-9]+\.[0-9]*|[0-9]/[0-9])';
     my $symop_component =
         "(?:(?:-|\\+)?$symop_term|" .
         "(?:-|\\+)?$symop_term(?:-|\\+)$symop_term|" .
